:mod:`qt_binder.widgets`
========================

:ref:`Value-added wrappers<value_added>` for Qt widgets.

.. currentmodule:: qt_binder.widgets

----

.. autoclass:: TextField
    :members:
    :undoc-members:
    :show-inheritance:

----

.. autoclass:: EditableComboBox
    :members:
    :undoc-members:
    :show-inheritance:

----

.. autoclass:: EnumDropDown
    :members:
    :undoc-members:
    :show-inheritance:

----

.. autoclass:: UIFile
    :members:
    :undoc-members:
    :show-inheritance:

----

.. autoclass:: BaseSlider
    :members:
    :undoc-members:
    :show-inheritance:

----

.. autoclass:: IntSlider
    :members:
    :undoc-members:
    :show-inheritance:

----

.. autoclass:: FloatSlider
    :members:
    :undoc-members:
    :show-inheritance:

----

.. autoclass:: LogSlider
    :members:
    :undoc-members:
    :show-inheritance:

----

.. autoclass:: RangeSlider
    :members:
    :undoc-members:
    :show-inheritance:
